EXEC [dbo].[__BuildMaster_AddStoredProcInfo]
    /* StoredProc_Name         */ 'AdminEdit_UpdateBuildStatus',
    /* Internal_Indicator      */ 'N',
    /* ReturnType_Name         */ 'void',
    /* DataTableNames_Csv      */ NULL,
    /* OutputPropertyNames_Csv */ NULL,
    /* Description_Text        */ 'Updates the status of a build.',
    /* Remarks_Text            */ NULL
GO

IF OBJECT_ID('[AdminEdit_UpdateBuildStatus]') IS NOT NULL DROP PROCEDURE [AdminEdit_UpdateBuildStatus]
GO

SET QUOTED_IDENTIFIER ON
GO

CREATE PROCEDURE [AdminEdit_UpdateBuildStatus]
(
	@Build_Id INT,
    @BuildStatus_Name VARCHAR(8)
)
AS
BEGIN

    SET NOCOUNT ON

BEGIN TRY
	BEGIN TRANSACTION

    IF EXISTS(SELECT *
	            FROM [Builds]
               WHERE [Build_Id] = @Build_Id
                 AND [BuildStatus_Name] = @BuildStatus_Name)
    BEGIN
        ROLLBACK
        RETURN
    END

    IF (@BuildStatus_Name = 'Rejected')
    BEGIN

        UPDATE [Builds]
           SET [BuildStatus_Name] = @BuildStatus_Name,
               [Rejection_Notes] = 'Rejected via Administrative Edit',
               [RejectedBy_User_Name] = dbo.Session_GetUserName(),
               [Rejected_Date] = GETUTCDATE(),
               [ModifiedBy_User_Name] = dbo.Session_GetUserName(),
               [ModifiedOn_Date] = GETUTCDATE()
		  FROM [Builds]
         WHERE [Build_Id] = @Build_Id

    END
    ELSE
    BEGIN

        UPDATE [Builds]
           SET [BuildStatus_Name] = @BuildStatus_Name,
               [Rejection_Notes] = NULL,
               [RejectedBy_User_Name] = NULL,
               [Rejected_Date] = NULL,
               [ModifiedBy_User_Name] = [dbo].Session_GetUserName(),
               [ModifiedOn_Date] = GETUTCDATE()
		  FROM [Builds]
         WHERE [Build_Id] = @Build_Id

    END

    COMMIT

END TRY BEGIN CATCH
	IF XACT_STATE()<>0 ROLLBACK
	EXEC [HandleError]
END CATCH

END
GO

GRANT EXECUTE ON [AdminEdit_UpdateBuildStatus] TO [BuildMasterUser_Role]
