EXEC [dbo].[__BuildMaster_AddStoredProcInfo]
    /* StoredProc_Name         */ 'Releases_PurgeReleaseData',
    /* Internal_Indicator      */ 'N',
    /* ReturnType_Name         */ 'void',
    /* DataTableNames_Csv      */ NULL,
    /* OutputPropertyNames_Csv */ NULL,
    /* Description_Text        */ 'Purges an entire release and all associated data from the system.'
GO

IF OBJECT_ID('[Releases_PurgeReleaseData]') IS NOT NULL DROP PROCEDURE [Releases_PurgeReleaseData]
GO

SET QUOTED_IDENTIFIER ON
GO

CREATE PROCEDURE [Releases_PurgeReleaseData]
(
	@Application_Id INT,
	@Release_Number RELEASENUMBER
) AS
BEGIN

SET NOCOUNT ON

BEGIN TRY
	BEGIN TRANSACTION

	DECLARE @Application_Name VARCHAR(50)
	SELECT @Application_Name = [Application_Name]
	  FROM [Applications]
	 WHERE [Application_Id] = @Application_Id

	DECLARE @Release_Id INT
	DECLARE @Release_Sequence BIGINT
	SELECT @Release_Id = [Release_Id],
	       @Release_Sequence = [Release_Sequence]
	  FROM [Releases]
	 WHERE [Application_Id] = @Application_Id
	   AND [Release_Number] = @Release_Number

	IF @Application_Name IS NULL
		RAISERROR('Application %i does not exist.', 16, 1, @Application_Id)
	
	IF @Release_Id IS NULL
		RAISERROR('Release %s of application %i does not exist.', 16, 1, @Release_Number, @Application_Id)

	DECLARE @Builds TABLE ([Build_Id] INT NOT NULL)
	INSERT INTO @Builds ([Build_Id])
	SELECT [Build_Id]
	  FROM [Builds]
	 WHERE [Release_Id] = @Release_Id

	DECLARE @Promotions TABLE ([Promotion_Id] INT NOT NULL)
	INSERT INTO @Promotions
	SELECT [Promotion_Id]
	  FROM [BuildPromotions]
	 WHERE [Build_Id] IN (SELECT [Build_Id] FROM @Builds)

	DECLARE @Executions TABLE ([Execution_Id] INT NOT NULL)
	INSERT INTO @Executions ([Execution_Id])
	SELECT [Execution_Id]
	  FROM [PipelineStageTargetExecutions]
	 WHERE [Promotion_Id] IN (SELECT [Promotion_Id] FROM @Promotions)

	DELETE
	  FROM [ReleaseNotes]
	 WHERE [Release_Id] = @Release_Id

	DELETE [ReleaseDeployables]
	 WHERE [Release_Id] = @Release_Id
	    OR [Referenced_Release_Id] = @Release_Id

	DELETE
	  FROM [BuildTestResults]
	 WHERE [Execution_Id] IN ( SELECT [Execution_Id] FROM @Executions )

	DELETE
	  FROM [ManualActionsInProgress]
	 WHERE [Execution_Id] IN (SELECT [Execution_Id] FROM @Executions)

	DELETE
	  FROM [Executions]
	 WHERE [Execution_Id] IN (SELECT [Execution_Id] FROM @Executions)

	DELETE
	  FROM [BuildPromotions]
	 WHERE [Promotion_Id] IN (SELECT [Promotion_Id] FROM @Promotions)

    DELETE
      FROM [BuildArtifacts]
     WHERE [Build_Id] IN (SELECT [Build_Id] FROM @Builds)

	DELETE
	  FROM [Builds]
	 WHERE [Build_Id] IN (SELECT [Build_Id] FROM @Builds)


	/* 3) Release */
	DELETE [Releases]
	 WHERE [Release_Id] = @Release_Id

    UPDATE [Releases]
       SET [Release_Sequence] = [Release_Sequence] - 1
     WHERE [Application_Id] = @Application_Id
       AND [Release_Sequence] > @Release_Sequence

	 /* Raise Event */
	EXEC [Events_RaiseEvent] 'RELDEL', @Application_Id, @Application_Name, @Release_Number

	COMMIT
END TRY BEGIN CATCH
	IF XACT_STATE()<>0 ROLLBACK
	EXEC [HandleError]
END CATCH

END
GO

GRANT EXECUTE ON [Releases_PurgeReleaseData] TO [BuildMasterUser_Role]
